/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import java.util.List;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.jface.viewers.ITreeContentProvider;

/**
 * The adapter content provider which offers contents of a multi-root tree
 * according to a normal content provider
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: C99AE660759E352AE4D3A9E7BF0C5AD2
 */
public class MultiRootTreeContentProvider extends TreeContentProviderBase {

	/** the root elements */
	private List<Object> roots;

	/** the real content provider */
	private ITreeContentProvider contentSupport;

	/** Constructor */
	public MultiRootTreeContentProvider(List<Object> roots,
			ITreeContentProvider contentSupport) {
		this.roots = roots;
		this.contentSupport = contentSupport;
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parentElement) {
		if (parentElement == roots) {
			return roots.toArray();
		}
		return contentSupport.getChildren(parentElement);
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if (roots.contains(element)) {
			return null;
		}
		return contentSupport.getParent(element);
	}
}