/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dnd.gef;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.EditPart;
import org.fortiss.tooling.base.ui.editpart.DiagramEditPartBase;
import org.fortiss.tooling.kernel.extension.data.IConnectionCompositionContext;

/**
 * A {@link ConnectionDropContext} stores the target edit part and the relative
 * position of the user's drag gesture, when the drag source is not in the same
 * diagram or editor. Depending on the concrete connection compositor this
 * information may be relevant.
 * <p>
 * The editpart can also be a diagram edit part, e.g. the background of some
 * diagram editor. In this case {@link #isRoot()} returns <code>true</code>.
 * <p>
 * Note that this context is usually used during a drag and drop operation
 * between a JFace viewer source (e.g a tree) and GEF-based graphical editor
 * when the result of the gesture should be handled by the connection compositor
 * service.
 * <P>
 * Example scenario: the user drags a model element from the navigator onto an
 * edit part in some editor and drops it there. As a result the dragged element
 * is connected to the target edit part's model element by reference link in the
 * model.
 * 
 * @see ConnectionDragContext
 * @see ElementDropContext
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: ED316779B97B25D6691EB4EF09E9A5DA
 */
public class ConnectionDropContext implements IConnectionCompositionContext {

	/** Drop target edit part */
	private final EditPart dropTarget;

	/** Position. */
	private final Point position;

	/** Constructor. */
	public ConnectionDropContext(EditPart dropTarget, Point position) {
		this.dropTarget = dropTarget;
		this.position = position;
	}

	/** Returns the position. */
	public Point getPosition() {
		return position;
	}

	/** Returns the drop target edit part. */
	public EditPart getDropTarget() {
		return dropTarget;
	}

	/** Returns whether drop target is root edit part (base). */
	public boolean isRoot() {
		return dropTarget instanceof DiagramEditPartBase;
	}
}
