/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dnd.gef;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.EditPart;
import org.fortiss.tooling.base.ui.editpart.DiagramEditPartBase;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;

/**
 * A {@link ElementDropContext} stores information obtained from user's drop
 * gesture, i.e. the target edit part and the location w.r.t. this edit part.
 * Depending on the concrete element compositor this information may be
 * relevant, e.g., to create proper initial layout information using the user's
 * gesture position.
 * <P>
 * The editpart can also be a diagram edit part, e.g. the background of some
 * diagram editor. In this case {@link #isRoot()} returns <code>true</code>.
 * <p>
 * Example scenario: an element of the model library view is dragged onto a
 * graphical editor. The model element is composed by some element compositor
 * and the gesture position is used to make the added element appear at the
 * user's target location.
 * 
 * @see ConnectionDragContext
 * @see ConnectionDropContext
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 01605EE831D52FCF0C2849835AC66C26
 */
public class ElementDropContext implements IElementCompositionContext {

	/** Drop target edit part */
	private final EditPart dropTarget;

	/** Position. */
	private final Point position;

	/** Constructor. */
	public ElementDropContext(EditPart dropTarget, Point position) {
		this.dropTarget = dropTarget;
		this.position = position;
	}

	/** Returns the position. */
	public Point getPosition() {
		return position;
	}

	/** Returns the drop target edit part. */
	public EditPart getDropTarget() {
		return dropTarget;
	}

	/** Returns whether drop target is root edit part (base). */
	public boolean isRoot() {
		return dropTarget instanceof DiagramEditPartBase;
	}
}
