/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.policy;

import static org.fortiss.tooling.base.ui.utils.ZoomUtils.determineZoom;
import static org.fortiss.tooling.base.ui.utils.ZoomUtils.fixChangeBoundRequest;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.Request;
import org.eclipse.gef.RequestConstants;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.UnexecutableCommand;
import org.eclipse.gef.editpolicies.NonResizableEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.fortiss.tooling.base.ui.editpart.ElementEditPartBase;
import org.fortiss.tooling.base.ui.editpart.command.MoveWithinDiagramCommand;

/**
 * The layout policy for diagrams. Element edit part children may be moved and
 * resized, while free connectors may only be moved.
 * 
 * @author wandinger
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: DC3E049397CBC5F1BA2B9181C1B6C9B7
 */
public class DiagramLayoutEditPolicy extends RelayCreateCommandEditPolicyBase {

	/** {@inheritDoc} */
	@Override
	protected EditPolicy createChildEditPolicy(EditPart child) {
		if (child instanceof ElementEditPartBase) {
			// elements may be resized
			return new ElementMoveAndSouthEastResizeEditPolicy();
		}
		// free connectors may only be moved
		return new NonResizableEditPolicy();
	}

	/** {@inheritDoc} */
	@Override
	public Command getCommand(Request request) {
		if (RequestConstants.REQ_RESIZE_CHILDREN.equals(request.getType())) {
			return getMoveChildrenCommand(request);
		}
		return super.getCommand(request);
	}

	/** {@inheritDoc} */
	@Override
	protected Command getMoveChildrenCommand(final Request request) {
		if (request instanceof ChangeBoundsRequest) {
			fixChangeBoundRequest((ChangeBoundsRequest) request,
					determineZoom(getHost().getRoot()));
			return new MoveWithinDiagramCommand((ChangeBoundsRequest) request);
		}
		return UnexecutableCommand.INSTANCE;
	}
}
