/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.actions;

import java.util.Collection;
import java.util.LinkedList;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.ActionFactory;
import org.fortiss.tooling.kernel.service.ICommandStackService;
import org.fortiss.tooling.kernel.service.IElementCompositorService;
import org.fortiss.tooling.kernel.ui.extension.base.EObjectActionBase;
import org.fortiss.tooling.kernel.ui.util.CopyPasteUtils;

/**
 * Action for cutting the current selection.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 57F104B047CEB608A996BF67133A4B7C
 */
public class CutAction extends EObjectActionBase<EObject> {

	/** Constructor. */
	public CutAction() {
		super("Cut", PlatformUI.getWorkbench().getSharedImages()
				.getImageDescriptor(ISharedImages.IMG_TOOL_CUT));
		setId(ActionFactory.CUT.getId());
	}

	/** {@inheritDoc} */
	@Override
	public void run() {
		ICommandStackService.INSTANCE.runAsCommand(getTarget(), new Runnable() {
			@Override
			public void run() {
				// currently we support only single element cutting
				// see ActionService.refresh()
				Collection<EObject> targets = new LinkedList<EObject>();
				targets.add(getTarget());
				CopyPasteUtils.copyToClipboard(targets);
				IElementCompositorService.INSTANCE.decompose(getTarget());
			}
		});
	}

	/** {@inheritDoc} */
	@Override
	protected boolean computeEnabled() {
		return IElementCompositorService.INSTANCE.canDecompose(getTarget());
	}
}
