/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.presentation;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * Label provider for model elements that have corresponding handlers.
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 0388B747C0F0AD71DE8C1A2777B73E81
 */
public class ModelElementLabelProvider extends LabelProvider {
	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if (element instanceof EObject) {
			IModelElementHandler<EObject> handler = IModelElementHandlerService.INSTANCE
					.getModelElementHandler((EObject) element);

			if (handler != null)
				return handler.getName((EObject) element);
		}
		if (element instanceof IStructuredSelection) {
			return getText(((IStructuredSelection) element).getFirstElement());
		}

		return super.getText(element);
	}

	/** {@inheritDoc} */
	@Override
	public Image getImage(Object element) {
		if (element instanceof EObject) {
			IModelElementHandler<EObject> handler = IModelElementHandlerService.INSTANCE
					.getModelElementHandler((EObject) element);

			if (handler != null)
				return handler.getIcon();
		}
		return super.getImage(element);
	}
}
