/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.base;

import java.util.Collections;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IConstraintChecker;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;

/**
 * Base implementation for {@link IConstraintChecker}. It checks the model
 * element against null and returns an unmodifiable empty list.
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 71E7C7994B89DFF53782600DB00DF8E1
 */
public abstract class ConstraintCheckerBase<T extends EObject> implements
		IConstraintChecker<T> {

	/** {@inheritDoc} */
	@Override
	public boolean isApplicable(T modelElement) {
		return modelElement != null;
	}

	/** {@inheritDoc} */
	@Override
	public List<? extends IConstraintViolation<? extends EObject>> apply(
			T modelElement) {
		return Collections.emptyList();
	}
}
