/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.base;

import java.util.ArrayList;
import java.util.List;

import org.conqat.lib.commons.collections.CollectionUtils;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IPrototypeProvider;
import org.fortiss.tooling.kernel.extension.data.Prototype;

/**
 * Base implementation for {@link IPrototypeProvider}s.
 * 
 * <p>
 * Sub-classes must implement {@link #registerPrototypes()} to register specific
 * prototypes using {@link #registerPrototype(String, EObject)} and
 * {@link #registerPrimaryPrototype(String, EObject)}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 62789E11E68D033A5D3B45087E7FD2C4
 */
public abstract class PrototypeProviderBase implements IPrototypeProvider {

	/** Stores the registered prototypes. */
	private final List<Prototype> prototypes = new ArrayList<Prototype>();

	/** Constructor. */
	public PrototypeProviderBase() {
		registerPrototypes();
	}

	/** Registers all prototypes. Sub-classes must override. */
	protected abstract void registerPrototypes();

	/** Registers the given {@link EObject} with the given name. */
	protected final void registerPrototype(String name, EObject prototype) {
		prototypes.add(new Prototype(name, prototype, false));
	}

	/**
	 * Registers the given {@link EObject} with the given name as primary
	 * prototype.
	 */
	protected final void registerPrimaryPrototype(String name, EObject prototype) {
		prototypes.add(new Prototype(name, prototype, true));
	}

	/** {@inheritDoc} */
	@Override
	public final List<Prototype> getPrototypes() {
		return CollectionUtils.asUnmodifiable(prototypes);
	}
}
