/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.wizard;

import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import org.conqat.ide.commons.ui.ECCSMCommonsImage;

/**
 * Wizard page that shows an error message and an error icon. Method
 * {@link #isPageComplete()} returns <code>false</code>. Unless method
 * {@link Wizard#canFinish()} is overwritten, the wizard will, hence, not be
 * finishable.
 * 
 * 
 * @author deissenb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 6D23094812D8A40AD9D18E337D7601BB
 */
public class ErrorWizardPage extends WizardPage {

	/** The title. */
	private final String title;

	/** The message */
	private final String message;

	/** Create error page. */
	public ErrorWizardPage(String title, String message) {
		super(ErrorWizardPage.class.getName());
		this.title = title;
		this.message = message;
	}

	/** Returns <code>false</code>. */
	@Override
	public boolean isPageComplete() {
		return false;
	}

	/** {@inheritDoc} */
	public void createControl(Composite parent) {
		setTitle(title);
		setImageDescriptor(ECCSMCommonsImage.ERROR_WIZBAN.getImageDescriptor());
		Composite container = new Composite(parent, SWT.NULL);
		container.setLayout(new GridLayout(1, false));
		new Label(container, SWT.NULL).setText(message);
		setControl(container);
	}

}